/* Listing 4.1 Creating a Database Reserving 25MB */
USE master
GO
CREATE DATABASE Frogger ON PRIMARY
( NAME = FroggerData,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\FroggerData.mdf',
  SIZE = 20MB,
  MAXSIZE = 100MB,
  FILEGROWTH = 10MB  )
LOG ON
( NAME = FroggerLog,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\FroggerLog.ldf',
  SIZE = 5MB,
  MAXSIZE = 15MB,
  FILEGROWTH = 1MB )
GO



/* Listing 4.2 Creating a Database That Spans Multiple Files */
USE master
GO
CREATE DATABASE Leap ON PRIMARY
( NAME = LeapData1,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\LeapData1.mdf',
  SIZE = 5,
  MAXSIZE = 20,
  FILEGROWTH = 1 ),
( NAME = LeapData2,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\LeapData2.ndf',
  SIZE = 5,
  MAXSIZE = 20,
  FILEGROWTH = 5 )
LOG ON
( NAME = LeapLog1,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\LeapLog1.ldf',
  SIZE = 2,
  MAXSIZE = 20,
  FILEGROWTH = 1 ),
( NAME = LeapLog2,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\LeapLog2.ldf',
  SIZE = 2,
  MAXSIZE = 10,
  FILEGROWTH = 2 )
GO



/* Listing 4.3 Creating a Database That Uses a 
 * Non-Ddefault SQL Server 2000 Collation Sequence */
USE master
GO
CREATE DATABASE Swim ON PRIMARY
( NAME = SwimData,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\SwimData.mdf',
  SIZE = 20MB,
  MAXSIZE = 100MB,
  FILEGROWTH = 10MB  )
LOG ON
( NAME = SwimLog,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\SwimLog.ldf',
  SIZE = 5MB,
  MAXSIZE = 15MB,
  FILEGROWTH = 1MB )
COLLATE Latin1_General_CI_AI
GO


/* Listing 4.4 Adding a New Data File to the Croak Database */
ALTER DATABASE croak
ADD FILE
( NAME = CroakData2,
  FILENAME = 
'D:\Program Files\Microsoft SQL Server\MSSQL\Data\CroakData2.ndf',
  SIZE = 2,
  MAXSIZE = 10,
  FILEGROWTH = 2)

/* Run the above code first and view the results, then run this code */

ALTER DATABASE croak
ADD LOG FILE
( NAME = CroakLog2,
  FILENAME = 
'D:\Program Files\ Microsoft SQL Server\MSSQL\DATA\CroakLog2.ndf',
  SIZE = 2,
  MAXSIZE = 10,
  FILEGROWTH = 2)



/* Listing 4.5 Emptying the File and Using REMOVE FILE */
USE frogger
GO
DBCC SHRINKFILE (FroggerData2,EMPTYFILE)
GO
ALTER DATABASE Frogger REMOVE FILE FroggerData2



/* Renaming a Database */

USE master
GO
EXEC sp_dboption Frogger, 'Single User', True
EXEC sp_renamedb 'Frogger', 'TsingWa'
EXEC sp_dboption TsingWa, 'Single User', False
GO

/* Creating a new filegroup */
ALTER DATABASE Leap
ADD FILEGROUP LeapGroup1
GO


/* Adding a new file to the newly created filegroup */
ALTER DATABASE Leap
ADD FILE
(Name = LeapDataG1,
 FILENAME = 
'D:\PROGRAM FILES\Microsoft SQL Server\MSSQL\DATA\LeapDataG1.ndf',
 SIZE = 2)
TO FILEGROUP LeapGroup1
GO


*/ To mark your new filegroup as the default filegroup, run the following */
GO
ALTER DATABASE Leap
MODIFY FILEGROUP LeapGroup1 DEFAULT


/* To test your new default filegroup, you can add a 
 * new data file without specifying a filegroup */
USE pubs
GO
ALTER DATABASE Leap
ADD FILE
(NAME = LeapDataTest,
 FILENAME = 'D:\PROGRAM FILES\Microsoft SQL Server\MSSQL\DATA\LeapDataTest.ndf',
 SIZE = 2)
GO

/* To remove a filegroup, you must first make the default 
 * filegroup the PRIMARY filegroup. Then empty the files 
 * in the old filegroup. After you have emptyied the files, 
 * you can safely remove the files and then the filegroup. */
USE Leap
GO

ALTER DATABASE Leap
MODIFY FILEGROUP [PRIMARY] DEFAULT
GO

ALTER DATABASE Leap
REMOVE FILE LeapDataG1
Go

ALTER DATABASE Leap
REMOVE FILE LeapDataTest
GO

ALTER DATABASE Leap
REMOVE FILEGROUP LeapGroup1
GO

/* The DROP DATABASE statement enables you to drop 
 * multiple databases at one time. In this example, you will 
 * drop both the TsingWa (formerly Frogger) and the Croak 
 * databases. */
USE MASTER
GO
DROP DATABASE TsingWa, Croak, Leap, Swim
GO


