-- check on pubs (should be simple)
Select DATABASEPROPERTYEX('pubs','recovery')
-- but Model should be FULL in standard and Enterprise Editions
Select DATABASEPROPERTYEX('model','recovery')
-- change pubs to FULL
Alter Database pubs SET RECOVERY FULL
-- now check your handiwork...
Select DATABASEPROPERTYEX('pubs','recovery')

-- add a backup device
exec sp_addumpdevice 'disk', 'master_backup','d:\program files\Microsoft SQL Server\mssql\backup\master_backup.bak'

-- drop a backup device
-- (create one first so you can drop it successfully)
exec sp_addumpdevice 'disk', 'pubs_backup','d:\program files\Microsoft SQL Server\mssql\backup\pubs_backup.bak'
-- now put a backup in there
backup database pubs to pubs_backup with init
-- now drop it
exec sp_dropdevice 'pubs_backup'
-- notice the file is still there if you look in explorer
-- put it back again...
exec sp_addumpdevice 'disk', 'pubs_backup','d:\program files\Microsoft SQL Server\mssql\backup\pubs_backup.bak'
-- and now drop it but delete the backup file as well
exec sp_dropdevice 'pubs_backup','delfile'
-- and now the file is gone.

-- look for installed devices
exec sp_helpdevice

-- Check for database consistency
DBCC CHECKDB ('pubs') With NO_INFOMSGS, TABLERESULTS

DBCC CHECKDB ('pubs') With TABLERESULTS

DBCC CHECKCATALOG('Pubs')

-- Perform a backup
exec sp_addumpdevice 'disk', 'pubs_backup',
'd:\program files\Microsoft SQL Server\mssql\backup\pubs_backup.bak'
go
use pubs
dbcc checkdb ('pubs') With NO_INFOMSGS
BACKUP DATABASE pubs to pubs_backup WITH INIT

-- and now a tape backup
exec sp_addumpdevice 'tape', 'pubs_tape_backup', '\\.\tape0'
use pubs
dbcc checkdb ('pubs') With NO_INFOMSGS
BACKUP DATABASE pubs to pubs_tape_backup WITH FORMAT,
Retain_days = 30, MediaName='Pubs Backup Tape',
Blocksize=8192


-- OK, differential backup
use pubs
Create table backuptest (col1 int not null)
Insert backuptest values (1)
Go
BACKUP DATABASE pubs to pubs_backup WITH differential, NOINIT

-- setting the server-wide default media retention
exec sp_configure 'media retention',30
RECONFIGURE WITH OVERRIDE

Alter Database pubs SET RECOVERY FULL
--*************
-- LISTING 1 **
--*************
--SCRIPT BEGINS AT 6:00 AM
use pubs
go
dbcc checkdb ('pubs') With NO_INFOMSGS, TABLERESULTS
go
BACKUP DATABASE pubs to pubs_backup WITH FORMAT,
Retaindays = 30,MediaName='Pubs Backup Tape',
Blocksize=8192
Go

-- 6:05 AM
BACKUP LOG pubs to pubs_log_backup WITH INIT
Go
-- 10:00 AM
BACKUP LOG pubs to pubs_log_backup
Go
-- 12:00 PM
BACKUP DATABASE pubs to pubs_backup WITH DIFFERENTIAL,
NOINIT, NOSKIP, Retaindays = 30, MediaName='Pubs Backup Tape',
Blocksize=8192
Go

-- 2:00 PM
BACKUP LOG pubs to pubs_log_backup
Go

-- 6:00 PM
BACKUP LOG pubs to pubs_log_backup
Go

-- 8:00 PM
BACKUP DATABASE pubs to pubs_backup WITH DIFFERENTIAL,
NOINIT, NOSKIP, Retaindays = 30, MediaName='Pubs Backup Tape',
Blocksize=8192
Go

-- 10:00 PM
BACKUP LOG pubs to pubs_log_backup
Go

